@@ -1,4 +1,5 @@
 import json
+import os
 from utf_queue_client.clients.ubai_artifact_upload_request_producer import (
     UbaiArtifactUploadRequestProducer,
 )
@@ -11,7 +12,7 @@ from retry import retry
 import requests
 from otel_extensions import instrumented
 from opentelemetry import trace
-
+from utf_queue_client import DISABLE_SSL_VERIFICATION_DEFAULT
 from utf_queue_client.utils import prepare_queue_central_url
 
 MULTIPART_SIZE_THRESHOLD = 1000000
@@ -99,6 +100,10 @@ def upload_artifact_direct(file_path, metadata_dict):
         contents,
         base64_content,
     ) = UbaiArtifactUploadRequestProducer.extract_payload(file_path)
+    verify_ssl = not (
+        os.environ.get("DISABLE_SSL_VERIFICATION", DISABLE_SSL_VERIFICATION_DEFAULT)
+        == "true"
+    )
     span = trace.get_current_span()
     span.set_attribute("artifact.name", name)
     span.set_attribute("artifact.extension", extension)
@@ -115,14 +120,14 @@ def upload_artifact_direct(file_path, metadata_dict):
                 f"{artifact_api.api_client.configuration.host}/api/v1/artifact-upload-file",
                 files=files,
                 data={"metadata": json.dumps(metadata_dict)},
-                verify=get_or_make_ca_file()
+                verify=get_or_make_ca_file() if verify_ssl else False,
             )
             if resp.status_code != 200 and resp.status_code != 201:
                 raise RuntimeError(resp.content)
     else:
         span.set_attribute("multipart_upload", False)
         UbaiArtifactUploadRequestProducer.upload_artifact_direct(
-            name, extension, base64_content, metadata_dict
+            name, extension, base64_content, metadata_dict, verify_ssl=verify_ssl
         )
 
 
